@@ -19,7 +19,7 @@ class Database():
             port='3306',
             auth_plugin='mysql_native_password',
             use_pure=True,
-            ssl_disable=True
+            ssl={}
         )
         
         # check if database exists and create it if it doesn't exist
